Viking Macros
Available Derive Macros
EnumDisplay: Adds the Display trait to enums and can modify their string representation using helper attributes.EnumVec: Puts all variants in a Vec.
Derive Macros
- Enum
Display - Implements the Display trait for enums. Using [convert_case] crate for the conversion.
- EnumVec
- Implements the trait EnumVec, by adding all enum variants to a [Vec].